@@ -190,18 +190,38 @@ class ContactCenterInsightsTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.create_issue_model: gapic_v1.method.wrap_method(
+                self.create_issue_model, default_timeout=None, client_info=client_info,
+            ),
+            self.update_issue_model: gapic_v1.method.wrap_method(
+                self.update_issue_model, default_timeout=None, client_info=client_info,
+            ),
             self.get_issue_model: gapic_v1.method.wrap_method(
                 self.get_issue_model, default_timeout=None, client_info=client_info,
             ),
             self.list_issue_models: gapic_v1.method.wrap_method(
                 self.list_issue_models, default_timeout=None, client_info=client_info,
             ),
+            self.delete_issue_model: gapic_v1.method.wrap_method(
+                self.delete_issue_model, default_timeout=None, client_info=client_info,
+            ),
+            self.deploy_issue_model: gapic_v1.method.wrap_method(
+                self.deploy_issue_model, default_timeout=None, client_info=client_info,
+            ),
+            self.undeploy_issue_model: gapic_v1.method.wrap_method(
+                self.undeploy_issue_model,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.get_issue: gapic_v1.method.wrap_method(
                 self.get_issue, default_timeout=None, client_info=client_info,
             ),
             self.list_issues: gapic_v1.method.wrap_method(
                 self.list_issues, default_timeout=None, client_info=client_info,
             ),
+            self.update_issue: gapic_v1.method.wrap_method(
+                self.update_issue, default_timeout=None, client_info=client_info,
+            ),
             self.calculate_issue_model_stats: gapic_v1.method.wrap_method(
                 self.calculate_issue_model_stats,
                 default_timeout=None,
@@ -337,6 +357,24 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def create_issue_model(
+        self,
+    ) -> Callable[
+        [contact_center_insights.CreateIssueModelRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def update_issue_model(
+        self,
+    ) -> Callable[
+        [contact_center_insights.UpdateIssueModelRequest],
+        Union[resources.IssueModel, Awaitable[resources.IssueModel]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def get_issue_model(
         self,
@@ -358,6 +396,33 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def delete_issue_model(
+        self,
+    ) -> Callable[
+        [contact_center_insights.DeleteIssueModelRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def deploy_issue_model(
+        self,
+    ) -> Callable[
+        [contact_center_insights.DeployIssueModelRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def undeploy_issue_model(
+        self,
+    ) -> Callable[
+        [contact_center_insights.UndeployIssueModelRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def get_issue(
         self,
@@ -379,6 +444,15 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def update_issue(
+        self,
+    ) -> Callable[
+        [contact_center_insights.UpdateIssueRequest],
+        Union[resources.Issue, Awaitable[resources.Issue]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def calculate_issue_model_stats(
         self,
