@@ -437,10 +437,15 @@ class IssueAssignment(proto.Message):
         score (float):
             Score indicating the likelihood of the issue assignment.
             currently bounded on [0,1].
+        display_name (str):
+            Immutable. Display name of the assigned
+            issue. This field is set at time of analyis and
+            immutable since then.
     """
 
     issue = proto.Field(proto.STRING, number=1,)
     score = proto.Field(proto.DOUBLE, number=2,)
+    display_name = proto.Field(proto.STRING, number=3,)
 
 
 class CallAnnotation(proto.Message):
@@ -711,6 +716,9 @@ class IssueModel(proto.Message):
             the issue model was updated.
         state (google.cloud.contact_center_insights_v1.types.IssueModel.State):
             Output only. State of the model.
+        input_data_config (google.cloud.contact_center_insights_v1.types.IssueModel.InputDataConfig):
+            Configs for the input data that used to
+            create the issue model.
         training_stats (google.cloud.contact_center_insights_v1.types.IssueModelLabelStats):
             Output only. Immutable. The issue model's
             label statistics on its training data.
@@ -725,11 +733,32 @@ class IssueModel(proto.Message):
         UNDEPLOYING = 4
         DELETING = 5
 
+    class InputDataConfig(proto.Message):
+        r"""Configs for the input data used to create the issue model.
+        Attributes:
+            medium (google.cloud.contact_center_insights_v1.types.Conversation.Medium):
+                Medium of conversations used in training data. This field is
+                being deprecated. To specify the medium to be used in
+                training a new issue model, set the ``medium`` field on
+                ``filter``.
+            training_conversations_count (int):
+                Output only. Number of conversations used in
+                training. Output only.
+            filter (str):
+                A filter to reduce the conversations used for
+                training the model to a specific subset.
+        """
+
+        medium = proto.Field(proto.ENUM, number=1, enum="Conversation.Medium",)
+        training_conversations_count = proto.Field(proto.INT64, number=2,)
+        filter = proto.Field(proto.STRING, number=3,)
+
     name = proto.Field(proto.STRING, number=1,)
     display_name = proto.Field(proto.STRING, number=2,)
     create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
     update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
     state = proto.Field(proto.ENUM, number=5, enum=State,)
+    input_data_config = proto.Field(proto.MESSAGE, number=6, message=InputDataConfig,)
     training_stats = proto.Field(
         proto.MESSAGE, number=7, message="IssueModelLabelStats",
     )
@@ -834,6 +863,9 @@ class PhraseMatcher(proto.Message):
             The role whose utterances the phrase matcher should be
             matched against. If the role is ROLE_UNSPECIFIED it will be
             matched against any utterances in the transcript.
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The most recent time at which
+            the phrase matcher was updated.
     """
 
     class PhraseMatcherType(proto.Enum):
@@ -862,6 +894,9 @@ class PhraseMatcher(proto.Message):
     role_match = proto.Field(
         proto.ENUM, number=10, enum="ConversationParticipant.Role",
     )
+    update_time = proto.Field(
+        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+    )
 
 
 class PhraseMatchRuleGroup(proto.Message):
@@ -978,6 +1013,8 @@ class Settings(proto.Message):
                created.
             -  "export-insights-data": Notify each time an export is
                complete.
+            -  "update-conversation": Notify each time a conversation is
+               updated via UpdateConversation.
 
             Values are Pub/Sub topics. The format of each Pub/Sub topic
             is: projects/{project}/topics/{topic}
@@ -1228,9 +1265,16 @@ class ConversationParticipant(proto.Message):
     r"""The call participant speaking for a given utterance.
 
     Attributes:
+        dialogflow_participant_name (str):
+            The name of the participant provided by
+            Dialogflow. Format:
+            projects/{project}/locations/{location}/conversations/{conversation}/participants/{participant}
+        user_id (str):
+            A user-specified ID representing the
+            participant.
         dialogflow_participant (str):
-            The name of the Dialogflow participant.
-            Format:
+            Deprecated. Use ``dialogflow_participant_name`` instead. The
+            name of the Dialogflow participant. Format:
             projects/{project}/locations/{location}/conversations/{conversation}/participants/{participant}
         role (google.cloud.contact_center_insights_v1.types.ConversationParticipant.Role):
             The role of the participant.
@@ -1244,6 +1288,10 @@ class ConversationParticipant(proto.Message):
         END_USER = 3
         ANY_AGENT = 4
 
+    dialogflow_participant_name = proto.Field(
+        proto.STRING, number=5, oneof="participant",
+    )
+    user_id = proto.Field(proto.STRING, number=6, oneof="participant",)
     dialogflow_participant = proto.Field(proto.STRING, number=1,)
     role = proto.Field(proto.ENUM, number=2, enum=Role,)
 
